@@ -4,23 +4,23 @@ This module is used to control Hamilton ML600 syringe pump via the protocol1/RNO
 
 from __future__ import annotations
 
-from flowchem.components.stdlib import Pump
-from loguru import logger
 import string
 import time
 import warnings
 from dataclasses import dataclass
 from enum import IntEnum
-from typing import Optional, Set, TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional, Set
+
+import aioserial
+from loguru import logger
+
+from flowchem.components.stdlib import Pump
+from flowchem.exceptions import DeviceError, InvalidConfiguration
+from flowchem.units import flowchem_ureg
 
 if TYPE_CHECKING:
     import pint
 
-import aioserial
-
-from flowchem.exceptions import InvalidConfiguration, DeviceError
-from flowchem.units import flowchem_ureg
-
 
 @dataclass
 class Protocol1CommandTemplate:
@@ -48,10 +48,7 @@ class Protocol1CommandTemplate:
 class Protocol1Command(Protocol1CommandTemplate):
     """Class representing a pump command and its expected reply"""
 
-    PUMP_ADDRESS = {
-        pump_num: address
-        for (pump_num, address) in enumerate(string.ascii_lowercase[:16], start=1)
-    }
+    PUMP_ADDRESS = dict(enumerate(string.ascii_lowercase[:16], start=1))
     # i.e. PUMP_ADDRESS = {1: 'a', 2: 'b', 3: 'c', 4: 'd', ..., 16: 'p'}
     # Note ':' is used for broadcast within the daisy chain.
 
@@ -112,10 +109,10 @@ class HamiltonPumpIO:
 
         try:
             serial_object = aioserial.AioSerial(**configuration)
-        except aioserial.SerialException as e:
+        except aioserial.SerialException as serial_exception:
             raise InvalidConfiguration(
                 f"Cannot connect to the pump on the port <{configuration.get('port')}>"
-            ) from e
+            ) from serial_exception
 
         return cls(serial_object)
 
@@ -124,7 +121,7 @@ class HamiltonPumpIO:
         Ensure connection with pump + initialize
 
         Args:
-            hw_initialization: Whether each pumps has to be initialized. Note that this might be undesired!
+            hw_initialization: Whether each pump has to be initialized. Note that this might be undesired!
         """
         # This has to be run after each power cycle to assign addresses to pumps
         self.num_pump_connected = await self._assign_pump_address()
@@ -134,7 +131,7 @@ class HamiltonPumpIO:
 
     async def _assign_pump_address(self) -> int:
         """
-        To be run on init, auto assign addresses to pumps based on their position on the daisy chain!
+        To be run on init, auto assign addresses to pumps based on their position in the daisy chain.
         A custom command syntax with no addresses is used here so read and write has been rewritten
         """
         try:
@@ -143,20 +140,20 @@ class HamiltonPumpIO:
             raise InvalidConfiguration from e
 
         reply = await self._read_reply_async()
-        if reply and reply[:1] == "1":
-            # reply[1:2] should be the address of the last pump. However, this does not work reliably.
-            # So here we enumerate the pumps explicitly instead
-            last_pump = 0
-            for pump_num, address in Protocol1Command.PUMP_ADDRESS.items():
-                await self._write_async(f"{address}UR\r".encode("ascii"))
-                if "NV01" in await self._read_reply_async():
-                    last_pump = pump_num
-                else:
-                    break
-            logger.debug(f"Found {last_pump} pumps on {self._serial.port}!")
-            return int(last_pump)
-        else:
+        if not reply or reply[:1] != "1":
+
             raise InvalidConfiguration(f"No pump found on {self._serial.port}")
+        # reply[1:2] should be the address of the last pump. However, this does not work reliably.
+        # So here we enumerate the pumps explicitly instead
+        last_pump = 0
+        for pump_num, address in Protocol1Command.PUMP_ADDRESS.items():
+            await self._write_async(f"{address}UR\r".encode("ascii"))
+            if "NV01" in await self._read_reply_async():
+                last_pump = pump_num
+            else:
+                break
+        logger.debug(f"Found {last_pump} pumps on {self._serial.port}!")
+        return int(last_pump)
 
     async def _hw_init(self):
         """Send to all pumps the HW initialization command (i.e. homing)"""
@@ -179,7 +176,8 @@ class HamiltonPumpIO:
         logger.debug(f"Reply received: {reply_string}")
         return reply_string.decode("ascii")
 
-    def parse_response(self, response: str) -> str:
+    @staticmethod
+    def parse_response(response: str) -> str:
         """Split a received line in its components: success, reply"""
         status = response[:1]
         assert status in (
@@ -226,7 +224,7 @@ class HamiltonPumpIO:
 
 
 class ML600(Pump):
-    """ ML600 implementation according to docs. Tested on 61501-01 (single syringe).
+    """ML600 implementation according to docs. Tested on 61501-01 (single syringe).
 
     From docs:
     To determine the volume dispensed per step the total syringe volume is divided by
@@ -239,7 +237,7 @@ class ML600(Pump):
     # This class variable is used for daisy chains (i.e. multiple pumps on the same serial connection). Details below.
     _io_instances: Set[HamiltonPumpIO] = set()
     # The mutable object (a set) as class variable creates a shared state across all the instances.
-    # When several pumps are daisy chained on the same serial port, they need to all access the same Serial object,
+    # When several pumps are daisy-chained on the same serial port, they need to all access the same Serial object,
     # because access to the serial port is exclusive by definition (also locking there ensure thread safe operations).
     # FYI it is a borg idiom https://www.oreilly.com/library/view/python-cookbook/0596001673/ch05s23.html
 
@@ -299,11 +297,12 @@ class ML600(Pump):
         # Syringe pumps only perform linear movement, and the volume displaced is function of the syringe loaded.
         try:
             self.syringe_volume = flowchem_ureg(syringe_volume)
-        except AttributeError as e:
-            raise InvalidConfiguration(f"{self.__class__.__name__}:{self.name} "
-                                       f"Syringe volume must be a string parsable as pint.Quantity!\n"
-                                       f"It is now a {type(syringe_volume)}: {syringe_volume} ") from e
-
+        except AttributeError as attribute_error:
+            raise InvalidConfiguration(
+                f"{self.__class__.__name__}:{self.name} "
+                f"Syringe volume must be a string parsable as pint.Quantity!\n"
+                f"It is now a {type(syringe_volume)}: {syringe_volume} "
+            ) from attribute_error
 
         if self.syringe_volume.m_as("ml") not in ML600.VALID_SYRINGE_VOLUME:
             raise InvalidConfiguration(
@@ -549,14 +548,14 @@ class ML600(Pump):
             await self.wait_until_idle()
 
     async def get_return_steps(self) -> int:
-        """Return steps getter. Applied to the end of a downward syringe movement to removes mechanical slack."""
+        """Return steps' getter. Applied to the end of a downward syringe movement to removes mechanical slack."""
         steps = await self.send_command_and_read_reply(
             Protocol1CommandTemplate(command="YQN")
         )
         return int(steps)
 
     async def set_return_steps(self, target_steps: int):
-        """Return steps setter. Applied to the end of a downward syringe movement to removes mechanical slack."""
+        """Return steps' setter. Applied to the end of a downward syringe movement to removes mechanical slack."""
         set_return_steps_cmd = Protocol1CommandTemplate(command="YSN")
         await self.send_command_and_read_reply(
             set_return_steps_cmd, command_value=str(int(target_steps))
@@ -579,7 +578,7 @@ class ML600(Pump):
             return
 
         # Valve to position specified
-        await self.set_valve_position(from_valve, wait_for_movement_end=True)
+        await self.set_valve_position(from_valve)
         # Move up to target volume
         await self.to_volume(
             str(cur_vol + volume),
@@ -605,7 +604,7 @@ class ML600(Pump):
             return
 
         # Valve to position specified
-        await self.set_valve_position(to_valve, wait_for_movement_end=True)
+        await self.set_valve_position(to_valve)
         # Move up to target volume
         await self.to_volume(
             str(cur_vol - volume),
