@@ -1,9 +1,9 @@
 """ Connection reader + XML parser for Spinsolve replies """
 
+import queue
 import time
 import warnings
-import queue
-from typing import List
+from typing import List, Optional
 
 from lxml import etree
 
@@ -35,11 +35,11 @@ class Reader:
         self._replies: List[etree.Element] = []
         self._rcv_buffer = b""
 
-    def wait_for_reply(self, reply_type="", remove=True, timeout=1):
+    def wait_for_reply(self, reply_type="", timeout=1):
         """
         Awaits for a reply of type reply_type or up to timeout
         """
-        reply = self.get_last_reply(reply_type, remove)
+        reply = self.get_next_reply(reply_type)
 
         # If already available just return
         if reply is not None:
@@ -49,28 +49,28 @@ class Reader:
         # Only relevant if controlling remote devices over connections with significant latency
         start_time = time.time()
         while reply is None and time.time() < (start_time + timeout):
-            reply = self.get_last_reply(reply_type)
-            time.sleep(0.5)
+            reply = self.get_next_reply(reply_type)
+            time.sleep(0.1)
 
         if reply is None:
             raise RuntimeError("No reply received from device!")
 
         return reply
 
-    def get_last_reply(self, reply_type="", remove=True):
+    def get_next_reply(self, reply_type=""):
         """
-        Returns the last reply of given type
+        Returns the next reply of given type in self._replies.
         """
         self.fetch_replies()
 
-        for reply in reversed(self._replies):
-            # First tag in message is response type
-            if reply[0].tag.endswith(reply_type):
-                if remove:
-                    self._replies.remove(
-                        reply
-                    )  # yes, I am also surprised that this is possible ;)
-                return reply
+        valid_replies = [
+            reply for reply in self._replies if reply[0].tag.endswith(reply_type)
+        ]
+
+        if len(valid_replies) > 0:
+            first_valid_reply = valid_replies[0]
+            self._replies.remove(first_valid_reply)
+            return first_valid_reply
 
     def clear_replies(self, reply_type=""):
         """Remove old replies."""
@@ -88,45 +88,29 @@ class Reader:
         Fetch the unprocessed chunks from the queue and adds them to the reception buffer
         """
         while not self._queue.empty():
-            self._rcv_buffer += self._queue.get()
+            # From queue only complete replies thanks to readuntil(b"</Message>")
+            tree = self.parse_tree(self._queue.get())
             self._queue.task_done()
 
-        self.parse_buffer()
+            if tree:
+                self._replies.append(tree)
 
-    def parse_buffer(self):
-        """
-        Split then buffer into individual XML trees and parse them.
-        """
+            if tree and self.schema:
+                self.validate_tree(tree)
 
-        # Split buffer at each declaration to separate different trees
-        declaration = b'<?xml version="1.0" encoding="utf-8"?>'
-        trees = self._rcv_buffer.split(declaration)
+    def parse_tree(self, tree_string) -> Optional[etree.Element]:
+        """Parse an XML reply tree, add it to the replies and validate it (if the schema is available)."""
 
-        # Parse trees. (Buffer always starts with declaration, so split gives a tree[0] = b"" element that we skip
-        for tree in trees[1:]:
-            self.parse_tree(tree)
-
-        # Clear buffer
-        self._rcv_buffer = b""
-
-    def parse_tree(self, tree_string):
-        """
-        Parse an XML reply tree, add it to the replies and validate it (if the schema is available).
-        """
-
-        # Parse
         try:
-            root = etree.fromstring(tree_string, self.parser)
+            return etree.fromstring(tree_string, self.parser)
         except etree.XMLSyntaxError:
             warnings.warn(f"Cannot parse response XML {tree_string}")
             return None
 
-        # Add tree to replies
-        self._replies.append(root)
+    def validate_tree(self, tree: etree.Element):
+        """Validate the XML tree against the schema."""
 
-        # Validate
-        if self.schema:
-            try:
-                self.schema.validate(root)
-            except etree.XMLSyntaxError as e:
-                warnings.warn(f"Invalid XML received! [Validation error: {e}]")
+        try:
+            self.schema.validate(tree)
+        except etree.XMLSyntaxError as syntax_error:
+            warnings.warn(f"Invalid XML received! [Validation error: {syntax_error}]")
