@@ -1,4 +1,7 @@
+""" Vapourtec devices """
 try:
     from .R4_heater import R4Heater
+
+    __all__ = ["R4Heater"]
 except PermissionError:
     print("Vapourtec devices disabled - no command description found.")
