@@ -2,11 +2,11 @@
 import inspect
 import warnings
 
-from loguru import logger
 from fastapi import APIRouter
+from loguru import logger
 
-from flowchem.components.properties import ActiveComponent
 from flowchem import Spinsolve
+from flowchem.components.properties import ActiveComponent
 from flowchem.core.server.routers import spinsolve_get_router
 
 
@@ -37,12 +37,12 @@ class DeviceNode:
             else:
                 self.device = obj_type(**device_config)
             logger.debug(f"Created {self.device.name} instance: {self.device}")
-        except TypeError as e:
+        except TypeError as error:
             raise ConnectionError(
                 f"Wrong configuration provided for device: {device_config.get('name')} of type {obj_type}!\n"
                 f"Configuration: {device_config}\n"
                 f"Accepted parameters: {inspect.getfullargspec(obj_type).args}"
-            ) from e
+            ) from error
 
     @property
     def router(self):
@@ -64,7 +64,10 @@ class DeviceNode:
                     )
                 router = APIRouter()
 
-        router.prefix = f"/{self.safe_title}"
-        router.tags = [self.safe_title]
+        # Router name is lowercase with no whitespace
+        router_name = self.device.name.replace(" ", "").lower()
+
+        router.prefix = f"/{router_name}"
+        router.tags = [router_name]
         self._router = router
         return self._router
