@@ -4,20 +4,14 @@
 class DeviceError(BaseException):
     """Generic DeviceError"""
 
-    pass
-
 
 class InvalidConfiguration(DeviceError):
     """The configuration provided is not valid, e.g. no connection w/ device obtained"""
 
-    pass
-
 
 class ActuationError(DeviceError):
-    """The attepted move did not succeed"""
-
-    pass
+    """The attempted move did not succeed"""
 
 
 class ProtocolCancelled(Exception):
-    pass
+    """The protocol was cancelled by the user"""
